@@ -27,8 +27,8 @@
 /*
  * Define the SIP version number.
  */
-#define SIP_VERSION         0x04130e
-#define SIP_VERSION_STR     "4.19.14"
+#define SIP_VERSION         0x041319
+#define SIP_VERSION_STR     "4.19.25"
 
 
 #ifdef TRUE
@@ -145,7 +145,7 @@
 #define CLASS_NO_DEFAULT_CTORS  0x00200000  /* Don't create default ctors. */
 #define CLASS_QOBJECT_SUB   0x00400000  /* It is derived from QObject. */
 #define CLASS_DTOR_HOLD_GIL 0x00800000  /* The dtor holds the GIL. */
-#define CLASS_ASSIGN_HELPER 0x01000000  /* Generate an assignment helper. */
+#define CLASS_ARRAY_HELPER  0x01000000  /* Generate an array helper. */
 #define CLASS_NO_QMETAOBJECT    0x02000000  /* It has no QMetaObject. */
 #define CLASS_IS_TEMPLATE   0x04000000  /* It is a template class. */
 #define CLASS_IS_DEPRECATED 0x08000000  /* It is deprecated. */
@@ -188,8 +188,8 @@
 #define setIsQObjectSubClass(cd)    ((cd)->classflags |= CLASS_QOBJECT_SUB)
 #define isHoldGILDtor(cd)   ((cd)->classflags & CLASS_DTOR_HOLD_GIL)
 #define setIsHoldGILDtor(cd) ((cd)->classflags |= CLASS_DTOR_HOLD_GIL)
-#define assignmentHelper(cd) ((cd)->classflags & CLASS_ASSIGN_HELPER)
-#define setAssignmentHelper(cd) ((cd)->classflags |= CLASS_ASSIGN_HELPER)
+#define arrayHelper(cd)     ((cd)->classflags & CLASS_ARRAY_HELPER)
+#define setArrayHelper(cd)  ((cd)->classflags |= CLASS_ARRAY_HELPER)
 #define noPyQtQMetaObject(cd)   ((cd)->classflags & CLASS_NO_QMETAOBJECT)
 #define setPyQtNoQMetaObject(cd)    ((cd)->classflags |= CLASS_NO_QMETAOBJECT)
 #define isTemplateClass(cd) ((cd)->classflags & CLASS_IS_TEMPLATE)
@@ -222,6 +222,7 @@
 #define CLASS2_HIDDEN_NS    0x08        /* The namespace is hidden. */
 #define CLASS2_USE_TMPL_NAME    0x10    /* Use the template name. */
 #define CLASS2_NEEDS_SHADOW 0x20        /* The class needs a shadow class. */
+#define CLASS2_COPY_HELPER  0x40        /* Generate a copy helper. */
 
 #define isTemplateArg(cd)   ((cd)->classflags2 & CLASS2_TMPL_ARG)
 #define setTemplateArg(cd)  ((cd)->classflags2 |= CLASS2_TMPL_ARG)
@@ -234,8 +235,10 @@
 #define setHiddenNamespace(cd)  ((cd)->classflags2 |= CLASS2_HIDDEN_NS)
 #define useTemplateName(cd) ((cd)->classflags2 & CLASS2_USE_TMPL_NAME)
 #define setUseTemplateName(cd)  ((cd)->classflags2 |= CLASS2_USE_TMPL_NAME)
-#define needsShadow(cd)      ((cd)->classflags & CLASS2_NEEDS_SHADOW)
-#define setNeedsShadow(cd)   ((cd)->classflags |= CLASS2_NEEDS_SHADOW)
+#define needsShadow(cd)      ((cd)->classflags2 & CLASS2_NEEDS_SHADOW)
+#define setNeedsShadow(cd)   ((cd)->classflags2 |= CLASS2_NEEDS_SHADOW)
+#define copyHelper(cd)      ((cd)->classflags2 & CLASS2_COPY_HELPER)
+#define setCopyHelper(cd)   ((cd)->classflags2 |= CLASS2_COPY_HELPER)
 
 
 /* Handle ctor flags.  These are combined with the section flags. */
@@ -317,17 +320,14 @@
 
 /* Handle hierarchy flags. */
 
-#define HIER_IS_DUPLICATE   0x0001      /* It is a super class duplicate. */
-#define HIER_HAS_DUPLICATE  0x0002      /* It has a super class duplicate. */
-#define HIER_BEING_SET      0x0004      /* The MRO is being set. */
+#define HIER_BEING_SET      0x0001      /* The MRO is being set. */
+#define IN_A_DIAMOND        0x0002      /* The class is in a diamond. */
 
-#define isDuplicateSuper(m) ((m)->mroflags & HIER_IS_DUPLICATE)
-#define setIsDuplicateSuper(m)  ((m)->mroflags |= HIER_IS_DUPLICATE)
-#define hasDuplicateSuper(m)    ((m)->mroflags & HIER_HAS_DUPLICATE)
-#define setHasDuplicateSuper(m) ((m)->mroflags |= HIER_HAS_DUPLICATE)
 #define hierBeingSet(m)     ((m)->mroflags & HIER_BEING_SET)
 #define setHierBeingSet(m)  ((m)->mroflags |= HIER_BEING_SET)
 #define resetHierBeingSet(m)    ((m)->mroflags &= ~HIER_BEING_SET)
+#define inADiamond(m)       ((m)->mroflags & IN_A_DIAMOND)
+#define setInADiamond(m)    ((m)->mroflags |= IN_A_DIAMOND)
 
 
 /* Handle overload flags.  These are combined with the section flags. */
